# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SecretV1(pulumi.CustomResource):
    acl: pulumi.Output[dict]
    """
    Allows to control an access to a secret. Currently only the
    `read` operation is supported. If not specified, the secret is accessible
    project wide.

      * `read` (`dict`)
        * `created_at` (`str`) - The date the secret ACL was created.
        * `projectAccess` (`bool`) - Whether the secret is accessible project wide.
          Defaults to `true`.
        * `updated_at` (`str`) - The date the secret ACL was last updated.
        * `users` (`list`) - The list of user IDs, which are allowed to access the
          secret, when `project_access` is set to `false`.
    """
    algorithm: pulumi.Output[str]
    """
    Metadata provided by a user or system for informational purposes.
    """
    all_metadata: pulumi.Output[dict]
    """
    The map of metadata, assigned on the secret, which has been
    explicitly and implicitly added.
    """
    bit_length: pulumi.Output[float]
    """
    Metadata provided by a user or system for informational purposes.
    """
    content_types: pulumi.Output[dict]
    """
    The map of the content types, assigned on the secret.
    """
    created_at: pulumi.Output[str]
    """
    The date the secret ACL was created.
    """
    creator_id: pulumi.Output[str]
    """
    The creator of the secret.
    """
    expiration: pulumi.Output[str]
    """
    The expiration time of the secret in the RFC3339 timestamp format (e.g. `2019-03-09T12:58:49Z`). If omitted, a secret will never expire. Changing this creates a new secret.
    """
    metadata: pulumi.Output[dict]
    """
    Additional Metadata for the secret.
    """
    mode: pulumi.Output[str]
    """
    Metadata provided by a user or system for informational purposes.
    """
    name: pulumi.Output[str]
    """
    Human-readable name for the Secret. Does not have
    to be unique.
    """
    payload: pulumi.Output[str]
    """
    The secret's data to be stored. **payload\_content\_type** must also be supplied if **payload** is included.
    """
    payload_content_encoding: pulumi.Output[str]
    """
    (required if **payload** is encoded) The encoding used for the payload to be able to include it in the JSON request. Must be either `base64` or `binary`.
    """
    payload_content_type: pulumi.Output[str]
    """
    (required if **payload** is included) The media type for the content of the payload. Must be one of `text/plain`, `text/plain;charset=utf-8`, `text/plain; charset=utf-8`, `application/octet-stream`, `application/pkcs8`.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V1 KeyManager client.
    A KeyManager client is needed to create a secret. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    V1 secret.
    """
    secret_ref: pulumi.Output[str]
    """
    The secret reference / where to find the secret.
    """
    secret_type: pulumi.Output[str]
    """
    Used to indicate the type of secret being stored. For more information see [Secret types](https://docs.openstack.org/barbican/latest/api/reference/secret_types.html).
    """
    status: pulumi.Output[str]
    """
    The status of the secret.
    """
    updated_at: pulumi.Output[str]
    """
    The date the secret ACL was last updated.
    """
    def __init__(__self__, resource_name, opts=None, acl=None, algorithm=None, bit_length=None, expiration=None, metadata=None, mode=None, name=None, payload=None, payload_content_encoding=None, payload_content_type=None, region=None, secret_type=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a SecretV1 resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] acl: Allows to control an access to a secret. Currently only the
               `read` operation is supported. If not specified, the secret is accessible
               project wide.
        :param pulumi.Input[str] algorithm: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[float] bit_length: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[str] expiration: The expiration time of the secret in the RFC3339 timestamp format (e.g. `2019-03-09T12:58:49Z`). If omitted, a secret will never expire. Changing this creates a new secret.
        :param pulumi.Input[dict] metadata: Additional Metadata for the secret.
        :param pulumi.Input[str] mode: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[str] name: Human-readable name for the Secret. Does not have
               to be unique.
        :param pulumi.Input[str] payload: The secret's data to be stored. **payload\_content\_type** must also be supplied if **payload** is included.
        :param pulumi.Input[str] payload_content_encoding: (required if **payload** is encoded) The encoding used for the payload to be able to include it in the JSON request. Must be either `base64` or `binary`.
        :param pulumi.Input[str] payload_content_type: (required if **payload** is included) The media type for the content of the payload. Must be one of `text/plain`, `text/plain;charset=utf-8`, `text/plain; charset=utf-8`, `application/octet-stream`, `application/pkcs8`.
        :param pulumi.Input[str] region: The region in which to obtain the V1 KeyManager client.
               A KeyManager client is needed to create a secret. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               V1 secret.
        :param pulumi.Input[str] secret_type: Used to indicate the type of secret being stored. For more information see [Secret types](https://docs.openstack.org/barbican/latest/api/reference/secret_types.html).

        The **acl** object supports the following:

          * `read` (`pulumi.Input[dict]`)
            * `created_at` (`pulumi.Input[str]`) - The date the secret ACL was created.
            * `projectAccess` (`pulumi.Input[bool]`) - Whether the secret is accessible project wide.
              Defaults to `true`.
            * `updated_at` (`pulumi.Input[str]`) - The date the secret ACL was last updated.
            * `users` (`pulumi.Input[list]`) - The list of user IDs, which are allowed to access the
              secret, when `project_access` is set to `false`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['acl'] = acl
            __props__['algorithm'] = algorithm
            __props__['bit_length'] = bit_length
            __props__['expiration'] = expiration
            __props__['metadata'] = metadata
            __props__['mode'] = mode
            __props__['name'] = name
            __props__['payload'] = payload
            __props__['payload_content_encoding'] = payload_content_encoding
            __props__['payload_content_type'] = payload_content_type
            __props__['region'] = region
            __props__['secret_type'] = secret_type
            __props__['all_metadata'] = None
            __props__['content_types'] = None
            __props__['created_at'] = None
            __props__['creator_id'] = None
            __props__['secret_ref'] = None
            __props__['status'] = None
            __props__['updated_at'] = None
        super(SecretV1, __self__).__init__(
            'openstack:keymanager/secretV1:SecretV1',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, acl=None, algorithm=None, all_metadata=None, bit_length=None, content_types=None, created_at=None, creator_id=None, expiration=None, metadata=None, mode=None, name=None, payload=None, payload_content_encoding=None, payload_content_type=None, region=None, secret_ref=None, secret_type=None, status=None, updated_at=None):
        """
        Get an existing SecretV1 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] acl: Allows to control an access to a secret. Currently only the
               `read` operation is supported. If not specified, the secret is accessible
               project wide.
        :param pulumi.Input[str] algorithm: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[dict] all_metadata: The map of metadata, assigned on the secret, which has been
               explicitly and implicitly added.
        :param pulumi.Input[float] bit_length: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[dict] content_types: The map of the content types, assigned on the secret.
        :param pulumi.Input[str] created_at: The date the secret ACL was created.
        :param pulumi.Input[str] creator_id: The creator of the secret.
        :param pulumi.Input[str] expiration: The expiration time of the secret in the RFC3339 timestamp format (e.g. `2019-03-09T12:58:49Z`). If omitted, a secret will never expire. Changing this creates a new secret.
        :param pulumi.Input[dict] metadata: Additional Metadata for the secret.
        :param pulumi.Input[str] mode: Metadata provided by a user or system for informational purposes.
        :param pulumi.Input[str] name: Human-readable name for the Secret. Does not have
               to be unique.
        :param pulumi.Input[str] payload: The secret's data to be stored. **payload\_content\_type** must also be supplied if **payload** is included.
        :param pulumi.Input[str] payload_content_encoding: (required if **payload** is encoded) The encoding used for the payload to be able to include it in the JSON request. Must be either `base64` or `binary`.
        :param pulumi.Input[str] payload_content_type: (required if **payload** is included) The media type for the content of the payload. Must be one of `text/plain`, `text/plain;charset=utf-8`, `text/plain; charset=utf-8`, `application/octet-stream`, `application/pkcs8`.
        :param pulumi.Input[str] region: The region in which to obtain the V1 KeyManager client.
               A KeyManager client is needed to create a secret. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               V1 secret.
        :param pulumi.Input[str] secret_ref: The secret reference / where to find the secret.
        :param pulumi.Input[str] secret_type: Used to indicate the type of secret being stored. For more information see [Secret types](https://docs.openstack.org/barbican/latest/api/reference/secret_types.html).
        :param pulumi.Input[str] status: The status of the secret.
        :param pulumi.Input[str] updated_at: The date the secret ACL was last updated.

        The **acl** object supports the following:

          * `read` (`pulumi.Input[dict]`)
            * `created_at` (`pulumi.Input[str]`) - The date the secret ACL was created.
            * `projectAccess` (`pulumi.Input[bool]`) - Whether the secret is accessible project wide.
              Defaults to `true`.
            * `updated_at` (`pulumi.Input[str]`) - The date the secret ACL was last updated.
            * `users` (`pulumi.Input[list]`) - The list of user IDs, which are allowed to access the
              secret, when `project_access` is set to `false`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["acl"] = acl
        __props__["algorithm"] = algorithm
        __props__["all_metadata"] = all_metadata
        __props__["bit_length"] = bit_length
        __props__["content_types"] = content_types
        __props__["created_at"] = created_at
        __props__["creator_id"] = creator_id
        __props__["expiration"] = expiration
        __props__["metadata"] = metadata
        __props__["mode"] = mode
        __props__["name"] = name
        __props__["payload"] = payload
        __props__["payload_content_encoding"] = payload_content_encoding
        __props__["payload_content_type"] = payload_content_type
        __props__["region"] = region
        __props__["secret_ref"] = secret_ref
        __props__["secret_type"] = secret_type
        __props__["status"] = status
        __props__["updated_at"] = updated_at
        return SecretV1(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_ip_v4": "accessIpV4",
    "access_ip_v6": "accessIpV6",
    "access_key": "accessKey",
    "access_level": "accessLevel",
    "access_rules": "accessRules",
    "access_to": "accessTo",
    "access_type": "accessType",
    "address_scope_id": "addressScopeId",
    "admin_pass": "adminPass",
    "admin_state_up": "adminStateUp",
    "all_fixed_ips": "allFixedIps",
    "all_metadata": "allMetadata",
    "all_security_group_ids": "allSecurityGroupIds",
    "all_tags": "allTags",
    "allocation_pools": "allocationPools",
    "allocation_pools_collection": "allocationPoolsCollection",
    "allow_reauth": "allowReauth",
    "allowed_address_pairs": "allowedAddressPairs",
    "api_address": "apiAddress",
    "apiserver_port": "apiserverPort",
    "application_credential_id": "applicationCredentialId",
    "application_credential_name": "applicationCredentialName",
    "application_credential_secret": "applicationCredentialSecret",
    "associated_routers": "associatedRouters",
    "attach_mode": "attachMode",
    "auth_algorithm": "authAlgorithm",
    "auth_url": "authUrl",
    "availability_zone": "availabilityZone",
    "availability_zone_hints": "availabilityZoneHints",
    "backup_gigabytes": "backupGigabytes",
    "bit_length": "bitLength",
    "block_devices": "blockDevices",
    "cacert_file": "cacertFile",
    "cluster_distro": "clusterDistro",
    "cluster_template_id": "clusterTemplateId",
    "coe_version": "coeVersion",
    "compare_type": "compareType",
    "config_drive": "configDrive",
    "configuration_id": "configurationId",
    "conn_limit": "connLimit",
    "connection_limit": "connectionLimit",
    "consistency_group_id": "consistencyGroupId",
    "container_format": "containerFormat",
    "container_name": "containerName",
    "container_read": "containerRead",
    "container_ref": "containerRef",
    "container_sync_key": "containerSyncKey",
    "container_sync_to": "containerSyncTo",
    "container_version": "containerVersion",
    "container_write": "containerWrite",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_length": "contentLength",
    "content_type": "contentType",
    "content_types": "contentTypes",
    "copy_from": "copyFrom",
    "create_timeout": "createTimeout",
    "created_at": "createdAt",
    "creation_time": "creationTime",
    "creator_id": "creatorId",
    "default_domain": "defaultDomain",
    "default_pool_id": "defaultPoolId",
    "default_prefixlen": "defaultPrefixlen",
    "default_project_id": "defaultProjectId",
    "default_quota": "defaultQuota",
    "default_tls_container_ref": "defaultTlsContainerRef",
    "delayed_auth": "delayedAuth",
    "delete_after": "deleteAfter",
    "delete_at": "deleteAt",
    "delete_default_rules": "deleteDefaultRules",
    "destination_cidr": "destinationCidr",
    "destination_ip_address": "destinationIpAddress",
    "destination_port": "destinationPort",
    "detect_content_type": "detectContentType",
    "device_id": "deviceId",
    "device_owner": "deviceOwner",
    "disable_no_cache_header": "disableNoCacheHeader",
    "disable_rollback": "disableRollback",
    "discovery_url": "discoveryUrl",
    "disk_format": "diskFormat",
    "dns_assignments": "dnsAssignments",
    "dns_domain": "dnsDomain",
    "dns_ip": "dnsIp",
    "dns_name": "dnsName",
    "dns_nameserver": "dnsNameserver",
    "dns_nameservers": "dnsNameservers",
    "docker_storage_driver": "dockerStorageDriver",
    "docker_volume_size": "dockerVolumeSize",
    "domain_id": "domainId",
    "domain_name": "domainName",
    "driver_volume_type": "driverVolumeType",
    "dscp_mark": "dscpMark",
    "enable_dhcp": "enableDhcp",
    "enable_online_resize": "enableOnlineResize",
    "enable_snat": "enableSnat",
    "encapsulation_mode": "encapsulationMode",
    "encryption_algorithm": "encryptionAlgorithm",
    "endpoint_overrides": "endpointOverrides",
    "endpoint_region": "endpointRegion",
    "endpoint_type": "endpointType",
    "environment_opts": "environmentOpts",
    "expected_codes": "expectedCodes",
    "expires_at": "expiresAt",
    "export_locations": "exportLocations",
    "external_fixed_ips": "externalFixedIps",
    "external_gateway": "externalGateway",
    "external_network_id": "externalNetworkId",
    "external_v4_ip": "externalV4Ip",
    "external_v6_ip": "externalV6Ip",
    "extra_dhcp_options": "extraDhcpOptions",
    "extra_specs": "extraSpecs",
    "fixed_ip": "fixedIp",
    "fixed_ips": "fixedIps",
    "fixed_network": "fixedNetwork",
    "fixed_subnet": "fixedSubnet",
    "flavor_id": "flavorId",
    "flavor_name": "flavorName",
    "floating_ip": "floatingIp",
    "floating_ip_enabled": "floatingIpEnabled",
    "floating_ips": "floatingIps",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "gateway_ip": "gatewayIp",
    "group_id": "groupId",
    "has_replicas": "hasReplicas",
    "host_name": "hostName",
    "host_routes": "hostRoutes",
    "http_method": "httpMethod",
    "http_proxy": "httpProxy",
    "https_proxy": "httpsProxy",
    "ignore_change_password_upon_first_use": "ignoreChangePasswordUponFirstUse",
    "ignore_lockout_failure_attempts": "ignoreLockoutFailureAttempts",
    "ignore_password_expiry": "ignorePasswordExpiry",
    "ike_version": "ikeVersion",
    "ikepolicy_id": "ikepolicyId",
    "image_cache_path": "imageCachePath",
    "image_id": "imageId",
    "image_name": "imageName",
    "image_source_url": "imageSourceUrl",
    "injected_file_content_bytes": "injectedFileContentBytes",
    "injected_file_path_bytes": "injectedFilePathBytes",
    "injected_files": "injectedFiles",
    "insecure_registry": "insecureRegistry",
    "insert_headers": "insertHeaders",
    "instance_id": "instanceId",
    "ip_address": "ipAddress",
    "ip_version": "ipVersion",
    "ipsecpolicy_id": "ipsecpolicyId",
    "ipv6_address_mode": "ipv6AddressMode",
    "ipv6_ra_mode": "ipv6RaMode",
    "is_default": "isDefault",
    "is_domain": "isDomain",
    "is_public": "isPublic",
    "key_pair": "keyPair",
    "key_pairs": "keyPairs",
    "keypair_id": "keypairId",
    "l7policy_id": "l7policyId",
    "last_modified": "lastModified",
    "lb_method": "lbMethod",
    "lb_provider": "lbProvider",
    "listener_id": "listenerId",
    "loadbalancer_id": "loadbalancerId",
    "loadbalancer_provider": "loadbalancerProvider",
    "local_ep_group_id": "localEpGroupId",
    "local_file_path": "localFilePath",
    "local_id": "localId",
    "mac_address": "macAddress",
    "master_addresses": "masterAddresses",
    "master_count": "masterCount",
    "master_flavor": "masterFlavor",
    "master_lb_enabled": "masterLbEnabled",
    "max_burst_kbps": "maxBurstKbps",
    "max_kbps": "maxKbps",
    "max_prefixlen": "maxPrefixlen",
    "max_retries": "maxRetries",
    "max_retries_down": "maxRetriesDown",
    "member_id": "memberId",
    "metadata_items": "metadataItems",
    "min_disk_gb": "minDiskGb",
    "min_kbps": "minKbps",
    "min_prefixlen": "minPrefixlen",
    "min_ram_mb": "minRamMb",
    "monitor_ids": "monitorIds",
    "mount_point_base": "mountPointBase",
    "multi_factor_auth_enabled": "multiFactorAuthEnabled",
    "multi_factor_auth_rules": "multiFactorAuthRules",
    "network_driver": "networkDriver",
    "network_id": "networkId",
    "network_type": "networkType",
    "neutron_net_id": "neutronNetId",
    "neutron_subnet_id": "neutronSubnetId",
    "next_hop": "nextHop",
    "no_fixed_ip": "noFixedIp",
    "no_gateway": "noGateway",
    "no_proxy": "noProxy",
    "no_routers": "noRouters",
    "no_security_groups": "noSecurityGroups",
    "node_addresses": "nodeAddresses",
    "node_count": "nodeCount",
    "notification_topics": "notificationTopics",
    "object_id": "objectId",
    "object_manifest": "objectManifest",
    "object_type": "objectType",
    "os_type": "osType",
    "parent_id": "parentId",
    "payload_content_encoding": "payloadContentEncoding",
    "payload_content_type": "payloadContentType",
    "peer_address": "peerAddress",
    "peer_cidrs": "peerCidrs",
    "peer_ep_group_id": "peerEpGroupId",
    "peer_id": "peerId",
    "per_volume_gigabytes": "perVolumeGigabytes",
    "phase1_negotiation_mode": "phase1NegotiationMode",
    "policy_id": "policyId",
    "pool_id": "poolId",
    "port_id": "portId",
    "port_range_max": "portRangeMax",
    "port_range_min": "portRangeMin",
    "port_security_enabled": "portSecurityEnabled",
    "power_state": "powerState",
    "prefix_length": "prefixLength",
    "private_key": "privateKey",
    "project_domain_id": "projectDomainId",
    "project_domain_name": "projectDomainName",
    "project_id": "projectId",
    "protocol_port": "protocolPort",
    "public_key": "publicKey",
    "qos_policy_id": "qosPolicyId",
    "rbac_policy": "rbacPolicy",
    "redirect_pool_id": "redirectPoolId",
    "redirect_url": "redirectUrl",
    "registry_enabled": "registryEnabled",
    "remote_group_id": "remoteGroupId",
    "remote_ip_prefix": "remoteIpPrefix",
    "replication_type": "replicationType",
    "revision_number": "revisionNumber",
    "role_id": "roleId",
    "router_id": "routerId",
    "rx_tx_factor": "rxTxFactor",
    "scheduler_hints": "schedulerHints",
    "secret_ref": "secretRef",
    "secret_refs": "secretRefs",
    "secret_type": "secretType",
    "security_group": "securityGroup",
    "security_group_id": "securityGroupId",
    "security_group_ids": "securityGroupIds",
    "security_group_rule": "securityGroupRule",
    "security_group_rules": "securityGroupRules",
    "security_groups": "securityGroups",
    "security_service_ids": "securityServiceIds",
    "segmentation_id": "segmentationId",
    "server_group_members": "serverGroupMembers",
    "server_groups": "serverGroups",
    "server_type": "serverType",
    "service_id": "serviceId",
    "service_name": "serviceName",
    "service_type": "serviceType",
    "share_id": "shareId",
    "share_network_id": "shareNetworkId",
    "share_proto": "shareProto",
    "share_server_id": "shareServerId",
    "share_type": "shareType",
    "size_bytes": "sizeBytes",
    "snapshot_id": "snapshotId",
    "sni_container_refs": "sniContainerRefs",
    "source_ip_address": "sourceIpAddress",
    "source_port": "sourcePort",
    "source_replica": "sourceReplica",
    "source_vol_id": "sourceVolId",
    "stack_id": "stackId",
    "status_reason": "statusReason",
    "stop_before_destroy": "stopBeforeDestroy",
    "sub_ports": "subPorts",
    "subnet_id": "subnetId",
    "subnetpool_id": "subnetpoolId",
    "target_tenant": "targetTenant",
    "template_description": "templateDescription",
    "template_opts": "templateOpts",
    "tenant_id": "tenantId",
    "tenant_name": "tenantName",
    "timeout_client_data": "timeoutClientData",
    "timeout_member_connect": "timeoutMemberConnect",
    "timeout_member_data": "timeoutMemberData",
    "timeout_tcp_inspect": "timeoutTcpInspect",
    "tls_disabled": "tlsDisabled",
    "trans_id": "transId",
    "transform_protocol": "transformProtocol",
    "transparent_vlan": "transparentVlan",
    "update_at": "updateAt",
    "updated_at": "updatedAt",
    "updated_time": "updatedTime",
    "url_path": "urlPath",
    "use_octavia": "useOctavia",
    "user_data": "userData",
    "user_domain_id": "userDomainId",
    "user_domain_name": "userDomainName",
    "user_id": "userId",
    "user_name": "userName",
    "value_specs": "valueSpecs",
    "vendor_options": "vendorOptions",
    "verify_checksum": "verifyChecksum",
    "vip_address": "vipAddress",
    "vip_port_id": "vipPortId",
    "vip_subnet_id": "vipSubnetId",
    "volume_driver": "volumeDriver",
    "volume_id": "volumeId",
    "volume_type": "volumeType",
    "vpnservice_id": "vpnserviceId",
    "wait_until_associated": "waitUntilAssociated",
    "zone_id": "zoneId",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessIpV4": "access_ip_v4",
    "accessIpV6": "access_ip_v6",
    "accessKey": "access_key",
    "accessLevel": "access_level",
    "accessRules": "access_rules",
    "accessTo": "access_to",
    "accessType": "access_type",
    "addressScopeId": "address_scope_id",
    "adminPass": "admin_pass",
    "adminStateUp": "admin_state_up",
    "allFixedIps": "all_fixed_ips",
    "allMetadata": "all_metadata",
    "allSecurityGroupIds": "all_security_group_ids",
    "allTags": "all_tags",
    "allocationPools": "allocation_pools",
    "allocationPoolsCollection": "allocation_pools_collection",
    "allowReauth": "allow_reauth",
    "allowedAddressPairs": "allowed_address_pairs",
    "apiAddress": "api_address",
    "apiserverPort": "apiserver_port",
    "applicationCredentialId": "application_credential_id",
    "applicationCredentialName": "application_credential_name",
    "applicationCredentialSecret": "application_credential_secret",
    "associatedRouters": "associated_routers",
    "attachMode": "attach_mode",
    "authAlgorithm": "auth_algorithm",
    "authUrl": "auth_url",
    "availabilityZone": "availability_zone",
    "availabilityZoneHints": "availability_zone_hints",
    "backupGigabytes": "backup_gigabytes",
    "bitLength": "bit_length",
    "blockDevices": "block_devices",
    "cacertFile": "cacert_file",
    "clusterDistro": "cluster_distro",
    "clusterTemplateId": "cluster_template_id",
    "coeVersion": "coe_version",
    "compareType": "compare_type",
    "configDrive": "config_drive",
    "configurationId": "configuration_id",
    "connLimit": "conn_limit",
    "connectionLimit": "connection_limit",
    "consistencyGroupId": "consistency_group_id",
    "containerFormat": "container_format",
    "containerName": "container_name",
    "containerRead": "container_read",
    "containerRef": "container_ref",
    "containerSyncKey": "container_sync_key",
    "containerSyncTo": "container_sync_to",
    "containerVersion": "container_version",
    "containerWrite": "container_write",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentLength": "content_length",
    "contentType": "content_type",
    "contentTypes": "content_types",
    "copyFrom": "copy_from",
    "createTimeout": "create_timeout",
    "createdAt": "created_at",
    "creationTime": "creation_time",
    "creatorId": "creator_id",
    "defaultDomain": "default_domain",
    "defaultPoolId": "default_pool_id",
    "defaultPrefixlen": "default_prefixlen",
    "defaultProjectId": "default_project_id",
    "defaultQuota": "default_quota",
    "defaultTlsContainerRef": "default_tls_container_ref",
    "delayedAuth": "delayed_auth",
    "deleteAfter": "delete_after",
    "deleteAt": "delete_at",
    "deleteDefaultRules": "delete_default_rules",
    "destinationCidr": "destination_cidr",
    "destinationIpAddress": "destination_ip_address",
    "destinationPort": "destination_port",
    "detectContentType": "detect_content_type",
    "deviceId": "device_id",
    "deviceOwner": "device_owner",
    "disableNoCacheHeader": "disable_no_cache_header",
    "disableRollback": "disable_rollback",
    "discoveryUrl": "discovery_url",
    "diskFormat": "disk_format",
    "dnsAssignments": "dns_assignments",
    "dnsDomain": "dns_domain",
    "dnsIp": "dns_ip",
    "dnsName": "dns_name",
    "dnsNameserver": "dns_nameserver",
    "dnsNameservers": "dns_nameservers",
    "dockerStorageDriver": "docker_storage_driver",
    "dockerVolumeSize": "docker_volume_size",
    "domainId": "domain_id",
    "domainName": "domain_name",
    "driverVolumeType": "driver_volume_type",
    "dscpMark": "dscp_mark",
    "enableDhcp": "enable_dhcp",
    "enableOnlineResize": "enable_online_resize",
    "enableSnat": "enable_snat",
    "encapsulationMode": "encapsulation_mode",
    "encryptionAlgorithm": "encryption_algorithm",
    "endpointOverrides": "endpoint_overrides",
    "endpointRegion": "endpoint_region",
    "endpointType": "endpoint_type",
    "environmentOpts": "environment_opts",
    "expectedCodes": "expected_codes",
    "expiresAt": "expires_at",
    "exportLocations": "export_locations",
    "externalFixedIps": "external_fixed_ips",
    "externalGateway": "external_gateway",
    "externalNetworkId": "external_network_id",
    "externalV4Ip": "external_v4_ip",
    "externalV6Ip": "external_v6_ip",
    "extraDhcpOptions": "extra_dhcp_options",
    "extraSpecs": "extra_specs",
    "fixedIp": "fixed_ip",
    "fixedIps": "fixed_ips",
    "fixedNetwork": "fixed_network",
    "fixedSubnet": "fixed_subnet",
    "flavorId": "flavor_id",
    "flavorName": "flavor_name",
    "floatingIp": "floating_ip",
    "floatingIpEnabled": "floating_ip_enabled",
    "floatingIps": "floating_ips",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "gatewayIp": "gateway_ip",
    "groupId": "group_id",
    "hasReplicas": "has_replicas",
    "hostName": "host_name",
    "hostRoutes": "host_routes",
    "httpMethod": "http_method",
    "httpProxy": "http_proxy",
    "httpsProxy": "https_proxy",
    "ignoreChangePasswordUponFirstUse": "ignore_change_password_upon_first_use",
    "ignoreLockoutFailureAttempts": "ignore_lockout_failure_attempts",
    "ignorePasswordExpiry": "ignore_password_expiry",
    "ikeVersion": "ike_version",
    "ikepolicyId": "ikepolicy_id",
    "imageCachePath": "image_cache_path",
    "imageId": "image_id",
    "imageName": "image_name",
    "imageSourceUrl": "image_source_url",
    "injectedFileContentBytes": "injected_file_content_bytes",
    "injectedFilePathBytes": "injected_file_path_bytes",
    "injectedFiles": "injected_files",
    "insecureRegistry": "insecure_registry",
    "insertHeaders": "insert_headers",
    "instanceId": "instance_id",
    "ipAddress": "ip_address",
    "ipVersion": "ip_version",
    "ipsecpolicyId": "ipsecpolicy_id",
    "ipv6AddressMode": "ipv6_address_mode",
    "ipv6RaMode": "ipv6_ra_mode",
    "isDefault": "is_default",
    "isDomain": "is_domain",
    "isPublic": "is_public",
    "keyPair": "key_pair",
    "keyPairs": "key_pairs",
    "keypairId": "keypair_id",
    "l7policyId": "l7policy_id",
    "lastModified": "last_modified",
    "lbMethod": "lb_method",
    "lbProvider": "lb_provider",
    "listenerId": "listener_id",
    "loadbalancerId": "loadbalancer_id",
    "loadbalancerProvider": "loadbalancer_provider",
    "localEpGroupId": "local_ep_group_id",
    "localFilePath": "local_file_path",
    "localId": "local_id",
    "macAddress": "mac_address",
    "masterAddresses": "master_addresses",
    "masterCount": "master_count",
    "masterFlavor": "master_flavor",
    "masterLbEnabled": "master_lb_enabled",
    "maxBurstKbps": "max_burst_kbps",
    "maxKbps": "max_kbps",
    "maxPrefixlen": "max_prefixlen",
    "maxRetries": "max_retries",
    "maxRetriesDown": "max_retries_down",
    "memberId": "member_id",
    "metadataItems": "metadata_items",
    "minDiskGb": "min_disk_gb",
    "minKbps": "min_kbps",
    "minPrefixlen": "min_prefixlen",
    "minRamMb": "min_ram_mb",
    "monitorIds": "monitor_ids",
    "mountPointBase": "mount_point_base",
    "multiFactorAuthEnabled": "multi_factor_auth_enabled",
    "multiFactorAuthRules": "multi_factor_auth_rules",
    "networkDriver": "network_driver",
    "networkId": "network_id",
    "networkType": "network_type",
    "neutronNetId": "neutron_net_id",
    "neutronSubnetId": "neutron_subnet_id",
    "nextHop": "next_hop",
    "noFixedIp": "no_fixed_ip",
    "noGateway": "no_gateway",
    "noProxy": "no_proxy",
    "noRouters": "no_routers",
    "noSecurityGroups": "no_security_groups",
    "nodeAddresses": "node_addresses",
    "nodeCount": "node_count",
    "notificationTopics": "notification_topics",
    "objectId": "object_id",
    "objectManifest": "object_manifest",
    "objectType": "object_type",
    "osType": "os_type",
    "parentId": "parent_id",
    "payloadContentEncoding": "payload_content_encoding",
    "payloadContentType": "payload_content_type",
    "peerAddress": "peer_address",
    "peerCidrs": "peer_cidrs",
    "peerEpGroupId": "peer_ep_group_id",
    "peerId": "peer_id",
    "perVolumeGigabytes": "per_volume_gigabytes",
    "phase1NegotiationMode": "phase1_negotiation_mode",
    "policyId": "policy_id",
    "poolId": "pool_id",
    "portId": "port_id",
    "portRangeMax": "port_range_max",
    "portRangeMin": "port_range_min",
    "portSecurityEnabled": "port_security_enabled",
    "powerState": "power_state",
    "prefixLength": "prefix_length",
    "privateKey": "private_key",
    "projectDomainId": "project_domain_id",
    "projectDomainName": "project_domain_name",
    "projectId": "project_id",
    "protocolPort": "protocol_port",
    "publicKey": "public_key",
    "qosPolicyId": "qos_policy_id",
    "rbacPolicy": "rbac_policy",
    "redirectPoolId": "redirect_pool_id",
    "redirectUrl": "redirect_url",
    "registryEnabled": "registry_enabled",
    "remoteGroupId": "remote_group_id",
    "remoteIpPrefix": "remote_ip_prefix",
    "replicationType": "replication_type",
    "revisionNumber": "revision_number",
    "roleId": "role_id",
    "routerId": "router_id",
    "rxTxFactor": "rx_tx_factor",
    "schedulerHints": "scheduler_hints",
    "secretRef": "secret_ref",
    "secretRefs": "secret_refs",
    "secretType": "secret_type",
    "securityGroup": "security_group",
    "securityGroupId": "security_group_id",
    "securityGroupIds": "security_group_ids",
    "securityGroupRule": "security_group_rule",
    "securityGroupRules": "security_group_rules",
    "securityGroups": "security_groups",
    "securityServiceIds": "security_service_ids",
    "segmentationId": "segmentation_id",
    "serverGroupMembers": "server_group_members",
    "serverGroups": "server_groups",
    "serverType": "server_type",
    "serviceId": "service_id",
    "serviceName": "service_name",
    "serviceType": "service_type",
    "shareId": "share_id",
    "shareNetworkId": "share_network_id",
    "shareProto": "share_proto",
    "shareServerId": "share_server_id",
    "shareType": "share_type",
    "sizeBytes": "size_bytes",
    "snapshotId": "snapshot_id",
    "sniContainerRefs": "sni_container_refs",
    "sourceIpAddress": "source_ip_address",
    "sourcePort": "source_port",
    "sourceReplica": "source_replica",
    "sourceVolId": "source_vol_id",
    "stackId": "stack_id",
    "statusReason": "status_reason",
    "stopBeforeDestroy": "stop_before_destroy",
    "subPorts": "sub_ports",
    "subnetId": "subnet_id",
    "subnetpoolId": "subnetpool_id",
    "targetTenant": "target_tenant",
    "templateDescription": "template_description",
    "templateOpts": "template_opts",
    "tenantId": "tenant_id",
    "tenantName": "tenant_name",
    "timeoutClientData": "timeout_client_data",
    "timeoutMemberConnect": "timeout_member_connect",
    "timeoutMemberData": "timeout_member_data",
    "timeoutTcpInspect": "timeout_tcp_inspect",
    "tlsDisabled": "tls_disabled",
    "transId": "trans_id",
    "transformProtocol": "transform_protocol",
    "transparentVlan": "transparent_vlan",
    "updateAt": "update_at",
    "updatedAt": "updated_at",
    "updatedTime": "updated_time",
    "urlPath": "url_path",
    "useOctavia": "use_octavia",
    "userData": "user_data",
    "userDomainId": "user_domain_id",
    "userDomainName": "user_domain_name",
    "userId": "user_id",
    "userName": "user_name",
    "valueSpecs": "value_specs",
    "vendorOptions": "vendor_options",
    "verifyChecksum": "verify_checksum",
    "vipAddress": "vip_address",
    "vipPortId": "vip_port_id",
    "vipSubnetId": "vip_subnet_id",
    "volumeDriver": "volume_driver",
    "volumeId": "volume_id",
    "volumeType": "volume_type",
    "vpnserviceId": "vpnservice_id",
    "waitUntilAssociated": "wait_until_associated",
    "zoneId": "zone_id",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Rule(pulumi.CustomResource):
    action: pulumi.Output[str]
    """
    Action to be taken ( must be "allow" or "deny") when the
    firewall rule matches. Changing this updates the `action` of an existing
    firewall rule.
    """
    description: pulumi.Output[str]
    """
    A description for the firewall rule. Changing this
    updates the `description` of an existing firewall rule.
    """
    destination_ip_address: pulumi.Output[str]
    """
    The destination IP address on which the
    firewall rule operates. Changing this updates the `destination_ip_address`
    of an existing firewall rule.
    """
    destination_port: pulumi.Output[str]
    """
    The destination port on which the firewall
    rule operates. Changing this updates the `destination_port` of an existing
    firewall rule.
    """
    enabled: pulumi.Output[bool]
    """
    Enabled status for the firewall rule (must be "true"
    or "false" if provided - defaults to "true"). Changing this updates the
    `enabled` status of an existing firewall rule.
    """
    ip_version: pulumi.Output[float]
    """
    IP version, either 4 (default) or 6. Changing this
    updates the `ip_version` of an existing firewall rule.
    """
    name: pulumi.Output[str]
    """
    A unique name for the firewall rule. Changing this
    updates the `name` of an existing firewall rule.
    """
    protocol: pulumi.Output[str]
    """
    The protocol type on which the firewall rule operates.
    Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
    `protocol` of an existing firewall rule.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the v1 Compute client.
    A Compute client is needed to create a firewall rule. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    firewall rule.
    """
    source_ip_address: pulumi.Output[str]
    """
    The source IP address on which the firewall
    rule operates. Changing this updates the `source_ip_address` of an existing
    firewall rule.
    """
    source_port: pulumi.Output[str]
    """
    The source port on which the firewall
    rule operates. Changing this updates the `source_port` of an existing
    firewall rule.
    """
    tenant_id: pulumi.Output[str]
    """
    The owner of the firewall rule. Required if admin
    wants to create a firewall rule for another tenant. Changing this creates a
    new firewall rule.
    """
    value_specs: pulumi.Output[dict]
    """
    Map of additional options.
    """
    def __init__(__self__, resource_name, opts=None, action=None, description=None, destination_ip_address=None, destination_port=None, enabled=None, ip_version=None, name=None, protocol=None, region=None, source_ip_address=None, source_port=None, tenant_id=None, value_specs=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a v1 firewall rule resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Action to be taken ( must be "allow" or "deny") when the
               firewall rule matches. Changing this updates the `action` of an existing
               firewall rule.
        :param pulumi.Input[str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule.
        :param pulumi.Input[bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[float] ip_version: IP version, either 4 (default) or 6. Changing this
               updates the `ip_version` of an existing firewall rule.
        :param pulumi.Input[str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[str] protocol: The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule.
        :param pulumi.Input[str] region: The region in which to obtain the v1 Compute client.
               A Compute client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule.
        :param pulumi.Input[str] tenant_id: The owner of the firewall rule. Required if admin
               wants to create a firewall rule for another tenant. Changing this creates a
               new firewall rule.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if action is None:
                raise TypeError("Missing required property 'action'")
            __props__['action'] = action
            __props__['description'] = description
            __props__['destination_ip_address'] = destination_ip_address
            __props__['destination_port'] = destination_port
            __props__['enabled'] = enabled
            __props__['ip_version'] = ip_version
            __props__['name'] = name
            if protocol is None:
                raise TypeError("Missing required property 'protocol'")
            __props__['protocol'] = protocol
            __props__['region'] = region
            __props__['source_ip_address'] = source_ip_address
            __props__['source_port'] = source_port
            __props__['tenant_id'] = tenant_id
            __props__['value_specs'] = value_specs
        super(Rule, __self__).__init__(
            'openstack:firewall/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, action=None, description=None, destination_ip_address=None, destination_port=None, enabled=None, ip_version=None, name=None, protocol=None, region=None, source_ip_address=None, source_port=None, tenant_id=None, value_specs=None):
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Action to be taken ( must be "allow" or "deny") when the
               firewall rule matches. Changing this updates the `action` of an existing
               firewall rule.
        :param pulumi.Input[str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule.
        :param pulumi.Input[bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[float] ip_version: IP version, either 4 (default) or 6. Changing this
               updates the `ip_version` of an existing firewall rule.
        :param pulumi.Input[str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[str] protocol: The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule.
        :param pulumi.Input[str] region: The region in which to obtain the v1 Compute client.
               A Compute client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule.
        :param pulumi.Input[str] tenant_id: The owner of the firewall rule. Required if admin
               wants to create a firewall rule for another tenant. Changing this creates a
               new firewall rule.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["action"] = action
        __props__["description"] = description
        __props__["destination_ip_address"] = destination_ip_address
        __props__["destination_port"] = destination_port
        __props__["enabled"] = enabled
        __props__["ip_version"] = ip_version
        __props__["name"] = name
        __props__["protocol"] = protocol
        __props__["region"] = region
        __props__["source_ip_address"] = source_ip_address
        __props__["source_port"] = source_port
        __props__["tenant_id"] = tenant_id
        __props__["value_specs"] = value_specs
        return Rule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SubnetRoute(pulumi.CustomResource):
    destination_cidr: pulumi.Output[str]
    """
    CIDR block to match on the packet’s destination IP. Changing
    this creates a new routing entry.
    """
    next_hop: pulumi.Output[str]
    """
    IP address of the next hop gateway.  Changing
    this creates a new routing entry.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 networking client.
    A networking client is needed to configure a routing entry on a subnet. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    routing entry.
    """
    subnet_id: pulumi.Output[str]
    """
    ID of the subnet this routing entry belongs to. Changing
    this creates a new routing entry.
    """
    def __init__(__self__, resource_name, opts=None, destination_cidr=None, next_hop=None, region=None, subnet_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates a routing entry on a OpenStack V2 subnet.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a subnet. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        :param pulumi.Input[str] subnet_id: ID of the subnet this routing entry belongs to. Changing
               this creates a new routing entry.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if destination_cidr is None:
                raise TypeError("Missing required property 'destination_cidr'")
            __props__['destination_cidr'] = destination_cidr
            if next_hop is None:
                raise TypeError("Missing required property 'next_hop'")
            __props__['next_hop'] = next_hop
            __props__['region'] = region
            if subnet_id is None:
                raise TypeError("Missing required property 'subnet_id'")
            __props__['subnet_id'] = subnet_id
        super(SubnetRoute, __self__).__init__(
            'openstack:networking/subnetRoute:SubnetRoute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, destination_cidr=None, next_hop=None, region=None, subnet_id=None):
        """
        Get an existing SubnetRoute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] destination_cidr: CIDR block to match on the packet’s destination IP. Changing
               this creates a new routing entry.
        :param pulumi.Input[str] next_hop: IP address of the next hop gateway.  Changing
               this creates a new routing entry.
        :param pulumi.Input[str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to configure a routing entry on a subnet. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               routing entry.
        :param pulumi.Input[str] subnet_id: ID of the subnet this routing entry belongs to. Changing
               this creates a new routing entry.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["destination_cidr"] = destination_cidr
        __props__["next_hop"] = next_hop
        __props__["region"] = region
        __props__["subnet_id"] = subnet_id
        return SubnetRoute(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ClusterTemplate(pulumi.CustomResource):
    apiserver_port: pulumi.Output[float]
    cluster_distro: pulumi.Output[str]
    coe: pulumi.Output[str]
    created_at: pulumi.Output[str]
    dns_nameserver: pulumi.Output[str]
    docker_storage_driver: pulumi.Output[str]
    docker_volume_size: pulumi.Output[float]
    external_network_id: pulumi.Output[str]
    fixed_network: pulumi.Output[str]
    fixed_subnet: pulumi.Output[str]
    flavor: pulumi.Output[str]
    floating_ip_enabled: pulumi.Output[bool]
    http_proxy: pulumi.Output[str]
    https_proxy: pulumi.Output[str]
    image: pulumi.Output[str]
    insecure_registry: pulumi.Output[str]
    keypair_id: pulumi.Output[str]
    labels: pulumi.Output[dict]
    master_flavor: pulumi.Output[str]
    master_lb_enabled: pulumi.Output[bool]
    name: pulumi.Output[str]
    network_driver: pulumi.Output[str]
    no_proxy: pulumi.Output[str]
    project_id: pulumi.Output[str]
    public: pulumi.Output[bool]
    region: pulumi.Output[str]
    registry_enabled: pulumi.Output[bool]
    server_type: pulumi.Output[str]
    tls_disabled: pulumi.Output[bool]
    updated_at: pulumi.Output[str]
    user_id: pulumi.Output[str]
    volume_driver: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, apiserver_port=None, cluster_distro=None, coe=None, dns_nameserver=None, docker_storage_driver=None, docker_volume_size=None, external_network_id=None, fixed_network=None, fixed_subnet=None, flavor=None, floating_ip_enabled=None, http_proxy=None, https_proxy=None, image=None, insecure_registry=None, keypair_id=None, labels=None, master_flavor=None, master_lb_enabled=None, name=None, network_driver=None, no_proxy=None, public=None, region=None, registry_enabled=None, server_type=None, tls_disabled=None, volume_driver=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a V1 Magnum cluster template resource within OpenStack.


        ## Argument reference

        The following arguments are supported:

        * `region` - (Optional) The region in which to obtain the V1 Container Infra
            client. A Container Infra client is needed to create a cluster template. If
            omitted,the `region` argument of the provider is used. Changing this
            creates a new cluster template.

        * `name` - (Required) The name of the cluster template. Changing this updates
            the name of the existing cluster template.

        * `project_id` - (Optional) The project of the cluster template. Required if
            admin wants to create a cluster template in another project. Changing this
            creates a new cluster template.

        * `user_id` - (Optional) The user of the cluster template. Required if admin
            wants to create a cluster template for another user. Changing this creates
            a new cluster template.

        * `apiserver_port` - (Optional) The API server port for the Container
            Orchestration Engine for this cluster template. Changing this updates the
            API server port of the existing cluster template.

        * `coe` - (Required) The Container Orchestration Engine for this cluster
            template. Changing this updates the engine of the existing cluster
            template.

        * `cluster_distro` - (Optional) The distro for the cluster (fedora-atomic,
            coreos, etc.). Changing this updates the cluster distro of the existing
            cluster template.

        * `dns_nameserver` - (Optional) Address of the DNS nameserver that is used in
            nodes of the cluster. Changing this updates the DNS nameserver of the
            existing cluster template.

        * `docker_storage_driver` - (Optional) Docker storage driver. Changing this
            updates the Docker storage driver of the existing cluster template.

        * `docker_volume_size` - (Optional) The size (in GB) of the Docker volume.
            Changing this updates the Docker volume size of the existing cluster
            template.

        * `external_network_id` - (Optional) The ID of the external network that will
            be used for the cluster. Changing this updates the external network ID of
            the existing cluster template.

        * `fixed_network` - (Optional) The fixed network that will be attached to the
            cluster. Changing this updates the fixed network of the existing cluster
            template.

        * `fixed_subnet` - (Optional) The fixed subnet that will be attached to the
            cluster. Changing this updates the fixed subnet of the existing cluster
            template.

        * `flavor` - (Optional) The flavor for the nodes of the cluster. Can be set via
            the `OS_MAGNUM_FLAVOR` environment variable. Changing this updates the
            flavor of the existing cluster template.

        * `master_flavor` - (Optional) The flavor for the master nodes. Can be set via
            the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this updates
            the master flavor of the existing cluster template.

        * `floating_ip_enabled` - (Optional) Indicates whether created cluster should
            create floating IP for every node or not. Changing this updates the
            floating IP enabled attribute of the existing cluster template.

        * `http_proxy` - (Optional) The address of a proxy for receiving all HTTP
            requests and relay them. Changing this updates the HTTP proxy address of
            the existing cluster template.

        * `https_proxy` - (Optional) The address of a proxy for receiving all HTTPS
            requests and relay them. Changing this updates the HTTPS proxy address of
            the existing cluster template.

        * `image` - (Required) The reference to an image that is used for nodes of the
            cluster. Can be set via the `OS_MAGNUM_IMAGE` environment variable.
            Changing this updates the image attribute of the existing cluster template.

        * `insecure_registry` - (Optional) The insecure registry URL for the cluster
            template. Changing this updates the insecure registry attribute of the
            existing cluster template.

        * `keypair_id` - (Optional) The name of the Compute service SSH keypair.
            Changing this updates the keypair of the existing cluster template.

        * `labels` - (Optional) The list of key value pairs representing additional
            properties of the cluster template. Changing this updates the labels of the
            existing cluster template.

        * `master_lb_enabled` - (Optional) Indicates whether created cluster should
            has a loadbalancer for master nodes or not. Changing this updates the
            attribute of the existing cluster template.

        * `network_driver` - (Optional) The name of the driver for the container
            network. Changing this updates the network driver of the existing cluster
            template.

        * `no_proxy` - (Optional) A comma-separated list of IP addresses that shouldn't
            be used in the cluster. Changing this updates the no proxy list of the
            existing cluster template.

        * `public` - (Optional) Indicates whether cluster template should be public.
            Changing this updates the public attribute of the existing cluster
            template.

        * `registry_enabled` - (Optional) Indicates whether Docker registry is enabled
            in the cluster. Changing this updates the registry enabled attribute of the
            existing cluster template.

        * `server_type` - (Optional) The server type for the cluster template. Changing
            this updates the server type of the existing cluster template.

        * `tls_disabled` - (Optional) Indicates whether the TLS should be disabled in
            the cluster. Changing this updates the attribute of the existing cluster.

        * `volume_driver` - (Optional) The name of the driver that is used for the
            volumes of the cluster nodes. Changing this updates the volume driver of
            the existing cluster template.

        ## Attributes reference

        The following attributes are exported:

        * `region` - See Argument Reference above.
        * `name` - See Argument Reference above.
        * `project_id` - See Argument Reference above.
        * `created_at` - The time at which cluster template was created.
        * `updated_at` - The time at which cluster template was created.
        * `apiserver_port` - See Argument Reference above.
        * `coe` - See Argument Reference above.
        * `cluster_distro` - See Argument Reference above.
        * `dns_nameserver` - See Argument Reference above.
        * `docker_storage_driver` - See Argument Reference above.
        * `docker_volume_size` - See Argument Reference above.
        * `external_network_id` - See Argument Reference above.
        * `fixed_network` - See Argument Reference above.
        * `fixed_subnet` - See Argument Reference above.
        * `flavor` - See Argument Reference above.
        * `master_flavor` - See Argument Reference above.
        * `floating_ip_enabled` - See Argument Reference above.
        * `http_proxy` - See Argument Reference above.
        * `https_proxy` - See Argument Reference above.
        * `image` - See Argument Reference above.
        * `insecure_registry` - See Argument Reference above.
        * `keypair_id` - See Argument Reference above.
        * `labels` - See Argument Reference above.
        * `links` - A list containing associated cluster template links.
        * `master_lb_enabled` - See Argument Reference above.
        * `network_driver` - See Argument Reference above.
        * `no_proxy` - See Argument Reference above.
        * `public` - See Argument Reference above.
        * `registry_enabled` - See Argument Reference above.
        * `server_type` - See Argument Reference above.
        * `tls_disabled` - See Argument Reference above.
        * `volume_driver` - See Argument Reference above.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['apiserver_port'] = apiserver_port
            __props__['cluster_distro'] = cluster_distro
            if coe is None:
                raise TypeError("Missing required property 'coe'")
            __props__['coe'] = coe
            __props__['dns_nameserver'] = dns_nameserver
            __props__['docker_storage_driver'] = docker_storage_driver
            __props__['docker_volume_size'] = docker_volume_size
            __props__['external_network_id'] = external_network_id
            __props__['fixed_network'] = fixed_network
            __props__['fixed_subnet'] = fixed_subnet
            __props__['flavor'] = flavor
            __props__['floating_ip_enabled'] = floating_ip_enabled
            __props__['http_proxy'] = http_proxy
            __props__['https_proxy'] = https_proxy
            if image is None:
                raise TypeError("Missing required property 'image'")
            __props__['image'] = image
            __props__['insecure_registry'] = insecure_registry
            __props__['keypair_id'] = keypair_id
            __props__['labels'] = labels
            __props__['master_flavor'] = master_flavor
            __props__['master_lb_enabled'] = master_lb_enabled
            __props__['name'] = name
            __props__['network_driver'] = network_driver
            __props__['no_proxy'] = no_proxy
            __props__['public'] = public
            __props__['region'] = region
            __props__['registry_enabled'] = registry_enabled
            __props__['server_type'] = server_type
            __props__['tls_disabled'] = tls_disabled
            __props__['volume_driver'] = volume_driver
            __props__['created_at'] = None
            __props__['project_id'] = None
            __props__['updated_at'] = None
            __props__['user_id'] = None
        super(ClusterTemplate, __self__).__init__(
            'openstack:containerinfra/clusterTemplate:ClusterTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, apiserver_port=None, cluster_distro=None, coe=None, created_at=None, dns_nameserver=None, docker_storage_driver=None, docker_volume_size=None, external_network_id=None, fixed_network=None, fixed_subnet=None, flavor=None, floating_ip_enabled=None, http_proxy=None, https_proxy=None, image=None, insecure_registry=None, keypair_id=None, labels=None, master_flavor=None, master_lb_enabled=None, name=None, network_driver=None, no_proxy=None, project_id=None, public=None, region=None, registry_enabled=None, server_type=None, tls_disabled=None, updated_at=None, user_id=None, volume_driver=None):
        """
        Get an existing ClusterTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["apiserver_port"] = apiserver_port
        __props__["cluster_distro"] = cluster_distro
        __props__["coe"] = coe
        __props__["created_at"] = created_at
        __props__["dns_nameserver"] = dns_nameserver
        __props__["docker_storage_driver"] = docker_storage_driver
        __props__["docker_volume_size"] = docker_volume_size
        __props__["external_network_id"] = external_network_id
        __props__["fixed_network"] = fixed_network
        __props__["fixed_subnet"] = fixed_subnet
        __props__["flavor"] = flavor
        __props__["floating_ip_enabled"] = floating_ip_enabled
        __props__["http_proxy"] = http_proxy
        __props__["https_proxy"] = https_proxy
        __props__["image"] = image
        __props__["insecure_registry"] = insecure_registry
        __props__["keypair_id"] = keypair_id
        __props__["labels"] = labels
        __props__["master_flavor"] = master_flavor
        __props__["master_lb_enabled"] = master_lb_enabled
        __props__["name"] = name
        __props__["network_driver"] = network_driver
        __props__["no_proxy"] = no_proxy
        __props__["project_id"] = project_id
        __props__["public"] = public
        __props__["region"] = region
        __props__["registry_enabled"] = registry_enabled
        __props__["server_type"] = server_type
        __props__["tls_disabled"] = tls_disabled
        __props__["updated_at"] = updated_at
        __props__["user_id"] = user_id
        __props__["volume_driver"] = volume_driver
        return ClusterTemplate(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Monitor(pulumi.CustomResource):
    admin_state_up: pulumi.Output[bool]
    """
    The administrative state of the monitor.
    A valid value is true (UP) or false (DOWN).
    """
    delay: pulumi.Output[float]
    """
    The time, in seconds, between sending probes to members.
    """
    expected_codes: pulumi.Output[str]
    """
    Required for HTTP(S) types. Expected HTTP codes
    for a passing HTTP(S) monitor. You can either specify a single status like
    "200", or a range like "200-202".
    """
    http_method: pulumi.Output[str]
    """
    Required for HTTP(S) types. The HTTP method used
    for requests by the monitor. If this attribute is not specified, it
    defaults to "GET".
    """
    max_retries: pulumi.Output[float]
    """
    Number of permissible ping failures before
    changing the member's status to INACTIVE. Must be a number between 1
    and 10.
    """
    max_retries_down: pulumi.Output[float]
    """
    Number of permissible ping failures befor changing the member's
    status to ERROR. Must be a number between 1 and 10 (supported only in Octavia).
    Changing this updates the max_retries_down of the existing monitor.
    """
    name: pulumi.Output[str]
    """
    The Name of the Monitor.
    """
    pool_id: pulumi.Output[str]
    """
    The id of the pool that this monitor will be assigned to.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Networking client.
    A Networking client is needed to create an . If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    monitor.
    """
    tenant_id: pulumi.Output[str]
    """
    Required for admins. The UUID of the tenant who owns
    the monitor.  Only administrative users can specify a tenant UUID
    other than their own. Changing this creates a new monitor.
    """
    timeout: pulumi.Output[float]
    """
    Maximum number of seconds for a monitor to wait for a
    ping reply before it times out. The value must be less than the delay
    value.
    """
    type: pulumi.Output[str]
    """
    The type of probe, which is PING, TCP, HTTP, HTTPS,
    TLS-HELLO or UDP-CONNECT (supported only in Octavia), that is sent by the load
    balancer to verify the member state. Changing this creates a new monitor.
    """
    url_path: pulumi.Output[str]
    """
    Required for HTTP(S) types. URI path that will be
    accessed if monitor type is HTTP or HTTPS.
    """
    def __init__(__self__, resource_name, opts=None, admin_state_up=None, delay=None, expected_codes=None, http_method=None, max_retries=None, max_retries_down=None, name=None, pool_id=None, region=None, tenant_id=None, timeout=None, type=None, url_path=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a V2 monitor resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the monitor.
               A valid value is true (UP) or false (DOWN).
        :param pulumi.Input[float] delay: The time, in seconds, between sending probes to members.
        :param pulumi.Input[str] expected_codes: Required for HTTP(S) types. Expected HTTP codes
               for a passing HTTP(S) monitor. You can either specify a single status like
               "200", or a range like "200-202".
        :param pulumi.Input[str] http_method: Required for HTTP(S) types. The HTTP method used
               for requests by the monitor. If this attribute is not specified, it
               defaults to "GET".
        :param pulumi.Input[float] max_retries: Number of permissible ping failures before
               changing the member's status to INACTIVE. Must be a number between 1
               and 10.
        :param pulumi.Input[float] max_retries_down: Number of permissible ping failures befor changing the member's
               status to ERROR. Must be a number between 1 and 10 (supported only in Octavia).
               Changing this updates the max_retries_down of the existing monitor.
        :param pulumi.Input[str] name: The Name of the Monitor.
        :param pulumi.Input[str] pool_id: The id of the pool that this monitor will be assigned to.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an . If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               monitor.
        :param pulumi.Input[str] tenant_id: Required for admins. The UUID of the tenant who owns
               the monitor.  Only administrative users can specify a tenant UUID
               other than their own. Changing this creates a new monitor.
        :param pulumi.Input[float] timeout: Maximum number of seconds for a monitor to wait for a
               ping reply before it times out. The value must be less than the delay
               value.
        :param pulumi.Input[str] type: The type of probe, which is PING, TCP, HTTP, HTTPS,
               TLS-HELLO or UDP-CONNECT (supported only in Octavia), that is sent by the load
               balancer to verify the member state. Changing this creates a new monitor.
        :param pulumi.Input[str] url_path: Required for HTTP(S) types. URI path that will be
               accessed if monitor type is HTTP or HTTPS.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['admin_state_up'] = admin_state_up
            if delay is None:
                raise TypeError("Missing required property 'delay'")
            __props__['delay'] = delay
            __props__['expected_codes'] = expected_codes
            __props__['http_method'] = http_method
            if max_retries is None:
                raise TypeError("Missing required property 'max_retries'")
            __props__['max_retries'] = max_retries
            __props__['max_retries_down'] = max_retries_down
            __props__['name'] = name
            if pool_id is None:
                raise TypeError("Missing required property 'pool_id'")
            __props__['pool_id'] = pool_id
            __props__['region'] = region
            __props__['tenant_id'] = tenant_id
            if timeout is None:
                raise TypeError("Missing required property 'timeout'")
            __props__['timeout'] = timeout
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            __props__['url_path'] = url_path
        super(Monitor, __self__).__init__(
            'openstack:loadbalancer/monitor:Monitor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, admin_state_up=None, delay=None, expected_codes=None, http_method=None, max_retries=None, max_retries_down=None, name=None, pool_id=None, region=None, tenant_id=None, timeout=None, type=None, url_path=None):
        """
        Get an existing Monitor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the monitor.
               A valid value is true (UP) or false (DOWN).
        :param pulumi.Input[float] delay: The time, in seconds, between sending probes to members.
        :param pulumi.Input[str] expected_codes: Required for HTTP(S) types. Expected HTTP codes
               for a passing HTTP(S) monitor. You can either specify a single status like
               "200", or a range like "200-202".
        :param pulumi.Input[str] http_method: Required for HTTP(S) types. The HTTP method used
               for requests by the monitor. If this attribute is not specified, it
               defaults to "GET".
        :param pulumi.Input[float] max_retries: Number of permissible ping failures before
               changing the member's status to INACTIVE. Must be a number between 1
               and 10.
        :param pulumi.Input[float] max_retries_down: Number of permissible ping failures befor changing the member's
               status to ERROR. Must be a number between 1 and 10 (supported only in Octavia).
               Changing this updates the max_retries_down of the existing monitor.
        :param pulumi.Input[str] name: The Name of the Monitor.
        :param pulumi.Input[str] pool_id: The id of the pool that this monitor will be assigned to.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an . If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               monitor.
        :param pulumi.Input[str] tenant_id: Required for admins. The UUID of the tenant who owns
               the monitor.  Only administrative users can specify a tenant UUID
               other than their own. Changing this creates a new monitor.
        :param pulumi.Input[float] timeout: Maximum number of seconds for a monitor to wait for a
               ping reply before it times out. The value must be less than the delay
               value.
        :param pulumi.Input[str] type: The type of probe, which is PING, TCP, HTTP, HTTPS,
               TLS-HELLO or UDP-CONNECT (supported only in Octavia), that is sent by the load
               balancer to verify the member state. Changing this creates a new monitor.
        :param pulumi.Input[str] url_path: Required for HTTP(S) types. URI path that will be
               accessed if monitor type is HTTP or HTTPS.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["admin_state_up"] = admin_state_up
        __props__["delay"] = delay
        __props__["expected_codes"] = expected_codes
        __props__["http_method"] = http_method
        __props__["max_retries"] = max_retries
        __props__["max_retries_down"] = max_retries_down
        __props__["name"] = name
        __props__["pool_id"] = pool_id
        __props__["region"] = region
        __props__["tenant_id"] = tenant_id
        __props__["timeout"] = timeout
        __props__["type"] = type
        __props__["url_path"] = url_path
        return Monitor(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Policy(pulumi.CustomResource):
    audited: pulumi.Output[bool]
    """
    Audit status of the firewall policy
    (must be "true" or "false" if provided - defaults to "false").
    This status is set to "false" whenever the firewall policy or any of its
    rules are changed. Changing this updates the `audited` status of an existing
    firewall policy.
    """
    description: pulumi.Output[str]
    """
    A description for the firewall policy. Changing
    this updates the `description` of an existing firewall policy.
    """
    name: pulumi.Output[str]
    """
    A name for the firewall policy. Changing this
    updates the `name` of an existing firewall policy.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the v1 networking client.
    A networking client is needed to create a firewall policy. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    firewall policy.
    """
    rules: pulumi.Output[list]
    """
    An array of one or more firewall rules that comprise
    the policy. Changing this results in adding/removing rules from the
    existing firewall policy.
    """
    shared: pulumi.Output[bool]
    """
    Sharing status of the firewall policy (must be "true"
    or "false" if provided). If this is "true" the policy is visible to, and
    can be used in, firewalls in other tenants. Changing this updates the
    `shared` status of an existing firewall policy. Only administrative users
    can specify if the policy should be shared.
    """
    tenant_id: pulumi.Output[str]
    value_specs: pulumi.Output[dict]
    """
    Map of additional options.
    """
    def __init__(__self__, resource_name, opts=None, audited=None, description=None, name=None, region=None, rules=None, shared=None, tenant_id=None, value_specs=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a v1 firewall policy resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] audited: Audit status of the firewall policy
               (must be "true" or "false" if provided - defaults to "false").
               This status is set to "false" whenever the firewall policy or any of its
               rules are changed. Changing this updates the `audited` status of an existing
               firewall policy.
        :param pulumi.Input[str] description: A description for the firewall policy. Changing
               this updates the `description` of an existing firewall policy.
        :param pulumi.Input[str] name: A name for the firewall policy. Changing this
               updates the `name` of an existing firewall policy.
        :param pulumi.Input[str] region: The region in which to obtain the v1 networking client.
               A networking client is needed to create a firewall policy. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall policy.
        :param pulumi.Input[list] rules: An array of one or more firewall rules that comprise
               the policy. Changing this results in adding/removing rules from the
               existing firewall policy.
        :param pulumi.Input[bool] shared: Sharing status of the firewall policy (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. Only administrative users
               can specify if the policy should be shared.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['audited'] = audited
            __props__['description'] = description
            __props__['name'] = name
            __props__['region'] = region
            __props__['rules'] = rules
            __props__['shared'] = shared
            __props__['tenant_id'] = tenant_id
            __props__['value_specs'] = value_specs
        super(Policy, __self__).__init__(
            'openstack:firewall/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, audited=None, description=None, name=None, region=None, rules=None, shared=None, tenant_id=None, value_specs=None):
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] audited: Audit status of the firewall policy
               (must be "true" or "false" if provided - defaults to "false").
               This status is set to "false" whenever the firewall policy or any of its
               rules are changed. Changing this updates the `audited` status of an existing
               firewall policy.
        :param pulumi.Input[str] description: A description for the firewall policy. Changing
               this updates the `description` of an existing firewall policy.
        :param pulumi.Input[str] name: A name for the firewall policy. Changing this
               updates the `name` of an existing firewall policy.
        :param pulumi.Input[str] region: The region in which to obtain the v1 networking client.
               A networking client is needed to create a firewall policy. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall policy.
        :param pulumi.Input[list] rules: An array of one or more firewall rules that comprise
               the policy. Changing this results in adding/removing rules from the
               existing firewall policy.
        :param pulumi.Input[bool] shared: Sharing status of the firewall policy (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. Only administrative users
               can specify if the policy should be shared.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["audited"] = audited
        __props__["description"] = description
        __props__["name"] = name
        __props__["region"] = region
        __props__["rules"] = rules
        __props__["shared"] = shared
        __props__["tenant_id"] = tenant_id
        __props__["value_specs"] = value_specs
        return Policy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetFloatingIpResult:
    """
    A collection of values returned by getFloatingIp.
    """
    def __init__(__self__, address=None, all_tags=None, description=None, dns_domain=None, dns_name=None, fixed_ip=None, id=None, pool=None, port_id=None, region=None, status=None, tags=None, tenant_id=None):
        if address and not isinstance(address, str):
            raise TypeError("Expected argument 'address' to be a str")
        __self__.address = address
        if all_tags and not isinstance(all_tags, list):
            raise TypeError("Expected argument 'all_tags' to be a list")
        __self__.all_tags = all_tags
        """
        A set of string tags applied on the floating IP.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        if dns_domain and not isinstance(dns_domain, str):
            raise TypeError("Expected argument 'dns_domain' to be a str")
        __self__.dns_domain = dns_domain
        """
        The floating IP DNS domain. Available, when Neutron DNS
        extension is enabled.
        """
        if dns_name and not isinstance(dns_name, str):
            raise TypeError("Expected argument 'dns_name' to be a str")
        __self__.dns_name = dns_name
        """
        The floating IP DNS name. Available, when Neutron DNS extension
        is enabled.
        """
        if fixed_ip and not isinstance(fixed_ip, str):
            raise TypeError("Expected argument 'fixed_ip' to be a str")
        __self__.fixed_ip = fixed_ip
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if pool and not isinstance(pool, str):
            raise TypeError("Expected argument 'pool' to be a str")
        __self__.pool = pool
        if port_id and not isinstance(port_id, str):
            raise TypeError("Expected argument 'port_id' to be a str")
        __self__.port_id = port_id
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        __self__.region = region
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        __self__.tags = tags
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        __self__.tenant_id = tenant_id
class AwaitableGetFloatingIpResult(GetFloatingIpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFloatingIpResult(
            address=self.address,
            all_tags=self.all_tags,
            description=self.description,
            dns_domain=self.dns_domain,
            dns_name=self.dns_name,
            fixed_ip=self.fixed_ip,
            id=self.id,
            pool=self.pool,
            port_id=self.port_id,
            region=self.region,
            status=self.status,
            tags=self.tags,
            tenant_id=self.tenant_id)

def get_floating_ip(address=None,description=None,fixed_ip=None,pool=None,port_id=None,region=None,status=None,tags=None,tenant_id=None,opts=None):
    """
    Use this data source to get the ID of an available OpenStack floating IP.




    :param str address: The IP address of the floating IP.
    :param str description: Human-readable description of the floating IP.
    :param str fixed_ip: The specific IP address of the internal port which should be associated with the floating IP.
    :param str pool: The name of the pool from which the floating IP belongs to.
    :param str port_id: The ID of the port the floating IP is attached.
    :param str region: The region in which to obtain the V2 Neutron client.
           A Neutron client is needed to retrieve floating IP ids. If omitted, the
           `region` argument of the provider is used.
    :param str status: status of the floating IP (ACTIVE/DOWN).
    :param list tags: The list of floating IP tags to filter.
    :param str tenant_id: The owner of the floating IP.
    """
    __args__ = dict()


    __args__['address'] = address
    __args__['description'] = description
    __args__['fixedIp'] = fixed_ip
    __args__['pool'] = pool
    __args__['portId'] = port_id
    __args__['region'] = region
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['tenantId'] = tenant_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('openstack:networking/getFloatingIp:getFloatingIp', __args__, opts=opts).value

    return AwaitableGetFloatingIpResult(
        address=__ret__.get('address'),
        all_tags=__ret__.get('allTags'),
        description=__ret__.get('description'),
        dns_domain=__ret__.get('dnsDomain'),
        dns_name=__ret__.get('dnsName'),
        fixed_ip=__ret__.get('fixedIp'),
        id=__ret__.get('id'),
        pool=__ret__.get('pool'),
        port_id=__ret__.get('portId'),
        region=__ret__.get('region'),
        status=__ret__.get('status'),
        tags=__ret__.get('tags'),
        tenant_id=__ret__.get('tenantId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Service(pulumi.CustomResource):
    admin_state_up: pulumi.Output[bool]
    """
    The administrative state of the resource. Can either be up(true) or down(false).
    Changing this updates the administrative state of the existing service.
    """
    description: pulumi.Output[str]
    """
    The human-readable description for the service.
    Changing this updates the description of the existing service.
    """
    external_v4_ip: pulumi.Output[str]
    """
    The read-only external (public) IPv4 address that is used for the VPN service.
    """
    external_v6_ip: pulumi.Output[str]
    """
    The read-only external (public) IPv6 address that is used for the VPN service.
    """
    name: pulumi.Output[str]
    """
    The name of the service. Changing this updates the name of
    the existing service.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Networking client.
    A Networking client is needed to create a VPN service. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    service.
    """
    router_id: pulumi.Output[str]
    """
    The ID of the router. Changing this creates a new service.
    """
    status: pulumi.Output[str]
    """
    Indicates whether IPsec VPN service is currently operational. Values are ACTIVE, DOWN, BUILD, ERROR, PENDING_CREATE, PENDING_UPDATE, or PENDING_DELETE.
    """
    subnet_id: pulumi.Output[str]
    """
    SubnetID is the ID of the subnet. Default is null.
    """
    tenant_id: pulumi.Output[str]
    """
    The owner of the service. Required if admin wants to
    create a service for another project. Changing this creates a new service.
    """
    value_specs: pulumi.Output[dict]
    """
    Map of additional options.
    """
    def __init__(__self__, resource_name, opts=None, admin_state_up=None, description=None, name=None, region=None, router_id=None, subnet_id=None, tenant_id=None, value_specs=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a V2 Neutron VPN service resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the resource. Can either be up(true) or down(false).
               Changing this updates the administrative state of the existing service.
        :param pulumi.Input[str] description: The human-readable description for the service.
               Changing this updates the description of the existing service.
        :param pulumi.Input[str] name: The name of the service. Changing this updates the name of
               the existing service.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               service.
        :param pulumi.Input[str] router_id: The ID of the router. Changing this creates a new service.
        :param pulumi.Input[str] subnet_id: SubnetID is the ID of the subnet. Default is null.
        :param pulumi.Input[str] tenant_id: The owner of the service. Required if admin wants to
               create a service for another project. Changing this creates a new service.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['admin_state_up'] = admin_state_up
            __props__['description'] = description
            __props__['name'] = name
            __props__['region'] = region
            if router_id is None:
                raise TypeError("Missing required property 'router_id'")
            __props__['router_id'] = router_id
            __props__['subnet_id'] = subnet_id
            __props__['tenant_id'] = tenant_id
            __props__['value_specs'] = value_specs
            __props__['external_v4_ip'] = None
            __props__['external_v6_ip'] = None
            __props__['status'] = None
        super(Service, __self__).__init__(
            'openstack:vpnaas/service:Service',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, admin_state_up=None, description=None, external_v4_ip=None, external_v6_ip=None, name=None, region=None, router_id=None, status=None, subnet_id=None, tenant_id=None, value_specs=None):
        """
        Get an existing Service resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the resource. Can either be up(true) or down(false).
               Changing this updates the administrative state of the existing service.
        :param pulumi.Input[str] description: The human-readable description for the service.
               Changing this updates the description of the existing service.
        :param pulumi.Input[str] external_v4_ip: The read-only external (public) IPv4 address that is used for the VPN service.
        :param pulumi.Input[str] external_v6_ip: The read-only external (public) IPv6 address that is used for the VPN service.
        :param pulumi.Input[str] name: The name of the service. Changing this updates the name of
               the existing service.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a VPN service. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               service.
        :param pulumi.Input[str] router_id: The ID of the router. Changing this creates a new service.
        :param pulumi.Input[str] status: Indicates whether IPsec VPN service is currently operational. Values are ACTIVE, DOWN, BUILD, ERROR, PENDING_CREATE, PENDING_UPDATE, or PENDING_DELETE.
        :param pulumi.Input[str] subnet_id: SubnetID is the ID of the subnet. Default is null.
        :param pulumi.Input[str] tenant_id: The owner of the service. Required if admin wants to
               create a service for another project. Changing this creates a new service.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["admin_state_up"] = admin_state_up
        __props__["description"] = description
        __props__["external_v4_ip"] = external_v4_ip
        __props__["external_v6_ip"] = external_v6_ip
        __props__["name"] = name
        __props__["region"] = region
        __props__["router_id"] = router_id
        __props__["status"] = status
        __props__["subnet_id"] = subnet_id
        __props__["tenant_id"] = tenant_id
        __props__["value_specs"] = value_specs
        return Service(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetEndpointResult:
    """
    A collection of values returned by getEndpoint.
    """
    def __init__(__self__, endpoint_region=None, id=None, interface=None, name=None, region=None, service_id=None, service_name=None, service_type=None, url=None):
        if endpoint_region and not isinstance(endpoint_region, str):
            raise TypeError("Expected argument 'endpoint_region' to be a str")
        __self__.endpoint_region = endpoint_region
        """
        See Argument Reference above.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if interface and not isinstance(interface, str):
            raise TypeError("Expected argument 'interface' to be a str")
        __self__.interface = interface
        """
        See Argument Reference above.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        See Argument Reference above.
        """
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        __self__.region = region
        """
        See Argument Reference above.
        """
        if service_id and not isinstance(service_id, str):
            raise TypeError("Expected argument 'service_id' to be a str")
        __self__.service_id = service_id
        """
        See Argument Reference above.
        """
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        __self__.service_name = service_name
        """
        See Argument Reference above.
        """
        if service_type and not isinstance(service_type, str):
            raise TypeError("Expected argument 'service_type' to be a str")
        __self__.service_type = service_type
        """
        See Argument Reference above.
        """
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        __self__.url = url
        """
        The endpoint URL.
        """
class AwaitableGetEndpointResult(GetEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointResult(
            endpoint_region=self.endpoint_region,
            id=self.id,
            interface=self.interface,
            name=self.name,
            region=self.region,
            service_id=self.service_id,
            service_name=self.service_name,
            service_type=self.service_type,
            url=self.url)

def get_endpoint(endpoint_region=None,interface=None,name=None,region=None,service_id=None,service_name=None,service_type=None,opts=None):
    """
    Use this data source to get the ID of an OpenStack endpoint.

    > **Note:** This usually requires admin privileges.




    :param str endpoint_region: The region the endpoint is assigned to. The
           `region` and `endpoint_region` can be different.
    :param str interface: The endpoint interface. Valid values are `public`,
           `internal`, and `admin`. Default value is `public`
    :param str name: The name of the endpoint.
    :param str region: The region in which to obtain the V3 Keystone client.
           If omitted, the `region` argument of the provider is used.
    :param str service_id: The service id this endpoint belongs to.
    :param str service_name: The service name of the endpoint.
    :param str service_type: The service type of the endpoint.
    """
    __args__ = dict()


    __args__['endpointRegion'] = endpoint_region
    __args__['interface'] = interface
    __args__['name'] = name
    __args__['region'] = region
    __args__['serviceId'] = service_id
    __args__['serviceName'] = service_name
    __args__['serviceType'] = service_type
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('openstack:identity/getEndpoint:getEndpoint', __args__, opts=opts).value

    return AwaitableGetEndpointResult(
        endpoint_region=__ret__.get('endpointRegion'),
        id=__ret__.get('id'),
        interface=__ret__.get('interface'),
        name=__ret__.get('name'),
        region=__ret__.get('region'),
        service_id=__ret__.get('serviceId'),
        service_name=__ret__.get('serviceName'),
        service_type=__ret__.get('serviceType'),
        url=__ret__.get('url'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetQosBandwidthLimitRuleResult:
    """
    A collection of values returned by getQosBandwidthLimitRule.
    """
    def __init__(__self__, direction=None, id=None, max_burst_kbps=None, max_kbps=None, qos_policy_id=None, region=None):
        if direction and not isinstance(direction, str):
            raise TypeError("Expected argument 'direction' to be a str")
        __self__.direction = direction
        """
        See Argument Reference above.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if max_burst_kbps and not isinstance(max_burst_kbps, float):
            raise TypeError("Expected argument 'max_burst_kbps' to be a float")
        __self__.max_burst_kbps = max_burst_kbps
        """
        See Argument Reference above.
        """
        if max_kbps and not isinstance(max_kbps, float):
            raise TypeError("Expected argument 'max_kbps' to be a float")
        __self__.max_kbps = max_kbps
        """
        See Argument Reference above.
        """
        if qos_policy_id and not isinstance(qos_policy_id, str):
            raise TypeError("Expected argument 'qos_policy_id' to be a str")
        __self__.qos_policy_id = qos_policy_id
        """
        See Argument Reference above.
        """
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        __self__.region = region
        """
        See Argument Reference above.
        """
class AwaitableGetQosBandwidthLimitRuleResult(GetQosBandwidthLimitRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQosBandwidthLimitRuleResult(
            direction=self.direction,
            id=self.id,
            max_burst_kbps=self.max_burst_kbps,
            max_kbps=self.max_kbps,
            qos_policy_id=self.qos_policy_id,
            region=self.region)

def get_qos_bandwidth_limit_rule(max_burst_kbps=None,max_kbps=None,qos_policy_id=None,region=None,opts=None):
    """
    Use this data source to get the ID of an available OpenStack QoS bandwidth limit rule.




    :param float max_burst_kbps: The maximum burst size in kilobits of a QoS bandwidth limit rule.
    :param float max_kbps: The maximum kilobits per second of a QoS bandwidth limit rule.
    :param str qos_policy_id: The QoS policy reference.
    :param str region: The region in which to obtain the V2 Networking client.
           A Networking client is needed to create a Neutron QoS bandwidth limit rule. If omitted, the
           `region` argument of the provider is used.
    """
    __args__ = dict()


    __args__['maxBurstKbps'] = max_burst_kbps
    __args__['maxKbps'] = max_kbps
    __args__['qosPolicyId'] = qos_policy_id
    __args__['region'] = region
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('openstack:networking/getQosBandwidthLimitRule:getQosBandwidthLimitRule', __args__, opts=opts).value

    return AwaitableGetQosBandwidthLimitRuleResult(
        direction=__ret__.get('direction'),
        id=__ret__.get('id'),
        max_burst_kbps=__ret__.get('maxBurstKbps'),
        max_kbps=__ret__.get('maxKbps'),
        qos_policy_id=__ret__.get('qosPolicyId'),
        region=__ret__.get('region'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Keypair(pulumi.CustomResource):
    fingerprint: pulumi.Output[str]
    """
    The fingerprint of the public key.
    """
    name: pulumi.Output[str]
    """
    A unique name for the keypair. Changing this creates a new
    keypair.
    """
    private_key: pulumi.Output[str]
    """
    The generated private key when no public key is specified.
    """
    public_key: pulumi.Output[str]
    """
    A pregenerated OpenSSH-formatted public key.
    Changing this creates a new keypair. If a public key is not specified, then
    a public/private key pair will be automatically generated. If a pair is
    created, then destroying this resource means you will lose access to that
    keypair forever.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Compute client.
    Keypairs are associated with accounts, but a Compute client is needed to
    create one. If omitted, the `region` argument of the provider is used.
    Changing this creates a new keypair.
    """
    value_specs: pulumi.Output[dict]
    """
    Map of additional options.
    """
    def __init__(__self__, resource_name, opts=None, name=None, public_key=None, region=None, value_specs=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Keypair resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['name'] = name
            __props__['public_key'] = public_key
            __props__['region'] = region
            __props__['value_specs'] = value_specs
            __props__['fingerprint'] = None
            __props__['private_key'] = None
        super(Keypair, __self__).__init__(
            'openstack:compute/keypair:Keypair',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, fingerprint=None, name=None, private_key=None, public_key=None, region=None, value_specs=None):
        """
        Get an existing Keypair resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] fingerprint: The fingerprint of the public key.
        :param pulumi.Input[str] name: A unique name for the keypair. Changing this creates a new
               keypair.
        :param pulumi.Input[str] private_key: The generated private key when no public key is specified.
        :param pulumi.Input[str] public_key: A pregenerated OpenSSH-formatted public key.
               Changing this creates a new keypair. If a public key is not specified, then
               a public/private key pair will be automatically generated. If a pair is
               created, then destroying this resource means you will lose access to that
               keypair forever.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Compute client.
               Keypairs are associated with accounts, but a Compute client is needed to
               create one. If omitted, the `region` argument of the provider is used.
               Changing this creates a new keypair.
        :param pulumi.Input[dict] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["fingerprint"] = fingerprint
        __props__["name"] = name
        __props__["private_key"] = private_key
        __props__["public_key"] = public_key
        __props__["region"] = region
        __props__["value_specs"] = value_specs
        return Keypair(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ImageAccessAccept(pulumi.CustomResource):
    created_at: pulumi.Output[str]
    """
    The date the image membership was created.
    """
    image_id: pulumi.Output[str]
    """
    The proposed image ID.
    """
    member_id: pulumi.Output[str]
    """
    The member ID, e.g. the target project ID. Optional
    for admin accounts. Defaults to the current scope project ID.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Glance client.
    A Glance client is needed to manage Image memberships. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    membership.
    """
    schema: pulumi.Output[str]
    """
    The membership schema.
    """
    status: pulumi.Output[str]
    """
    The membership proposal status. Can either be
    `accepted`, `rejected` or `pending`.
    """
    updated_at: pulumi.Output[str]
    """
    The date the image membership was last updated.
    """
    def __init__(__self__, resource_name, opts=None, image_id=None, member_id=None, region=None, status=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages memberships status for the shared OpenStack Glance V2 Image within the
        destination project, which has a member proposal.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] image_id: The proposed image ID.
        :param pulumi.Input[str] member_id: The member ID, e.g. the target project ID. Optional
               for admin accounts. Defaults to the current scope project ID.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Glance client.
               A Glance client is needed to manage Image memberships. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               membership.
        :param pulumi.Input[str] status: The membership proposal status. Can either be
               `accepted`, `rejected` or `pending`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if image_id is None:
                raise TypeError("Missing required property 'image_id'")
            __props__['image_id'] = image_id
            __props__['member_id'] = member_id
            __props__['region'] = region
            if status is None:
                raise TypeError("Missing required property 'status'")
            __props__['status'] = status
            __props__['created_at'] = None
            __props__['schema'] = None
            __props__['updated_at'] = None
        super(ImageAccessAccept, __self__).__init__(
            'openstack:images/imageAccessAccept:ImageAccessAccept',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, created_at=None, image_id=None, member_id=None, region=None, schema=None, status=None, updated_at=None):
        """
        Get an existing ImageAccessAccept resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: The date the image membership was created.
        :param pulumi.Input[str] image_id: The proposed image ID.
        :param pulumi.Input[str] member_id: The member ID, e.g. the target project ID. Optional
               for admin accounts. Defaults to the current scope project ID.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Glance client.
               A Glance client is needed to manage Image memberships. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               membership.
        :param pulumi.Input[str] schema: The membership schema.
        :param pulumi.Input[str] status: The membership proposal status. Can either be
               `accepted`, `rejected` or `pending`.
        :param pulumi.Input[str] updated_at: The date the image membership was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["created_at"] = created_at
        __props__["image_id"] = image_id
        __props__["member_id"] = member_id
        __props__["region"] = region
        __props__["schema"] = schema
        __props__["status"] = status
        __props__["updated_at"] = updated_at
        return ImageAccessAccept(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Vip(pulumi.CustomResource):
    address: pulumi.Output[str]
    """
    The IP address of the vip. Changing this creates a new
    vip.
    """
    admin_state_up: pulumi.Output[bool]
    """
    The administrative state of the vip.
    Acceptable values are "true" and "false". Changing this value updates the
    state of the existing vip.
    """
    conn_limit: pulumi.Output[float]
    """
    The maximum number of connections allowed for the
    vip. Default is -1, meaning no limit. Changing this updates the conn_limit
    of the existing vip.
    """
    description: pulumi.Output[str]
    """
    Human-readable description for the vip. Changing
    this updates the description of the existing vip.
    """
    floating_ip: pulumi.Output[str]
    """
    A *Networking* Floating IP that will be associated
    with the vip. The Floating IP must be provisioned already.
    """
    name: pulumi.Output[str]
    """
    The name of the vip. Changing this updates the name of
    the existing vip.
    """
    persistence: pulumi.Output[dict]
    """
    Omit this field to prevent session persistence.
    The persistence object structure is documented below. Changing this updates
    the persistence of the existing vip.
    """
    pool_id: pulumi.Output[str]
    """
    The ID of the pool with which the vip is associated.
    Changing this updates the pool_id of the existing vip.
    """
    port: pulumi.Output[float]
    """
    The port on which to listen for client traffic. Changing
    this creates a new vip.
    """
    port_id: pulumi.Output[str]
    """
    Port UUID for this VIP at associated floating IP (if any).
    """
    protocol: pulumi.Output[str]
    """
    The protocol - can be either 'TCP, 'HTTP', or
    HTTPS'. Changing this creates a new vip.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Networking client.
    A Networking client is needed to create a VIP. If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    VIP.
    """
    subnet_id: pulumi.Output[str]
    """
    The network on which to allocate the vip's address. A
    tenant can only create vips on networks authorized by policy (e.g. networks
    that belong to them or networks that are shared). Changing this creates a
    new vip.
    """
    tenant_id: pulumi.Output[str]
    """
    The owner of the vip. Required if admin wants to
    create a vip member for another tenant. Changing this creates a new vip.
    """
    def __init__(__self__, resource_name, opts=None, address=None, admin_state_up=None, conn_limit=None, description=None, floating_ip=None, name=None, persistence=None, pool_id=None, port=None, protocol=None, region=None, subnet_id=None, tenant_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a V1 load balancer vip resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: The IP address of the vip. Changing this creates a new
               vip.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the vip.
               Acceptable values are "true" and "false". Changing this value updates the
               state of the existing vip.
        :param pulumi.Input[float] conn_limit: The maximum number of connections allowed for the
               vip. Default is -1, meaning no limit. Changing this updates the conn_limit
               of the existing vip.
        :param pulumi.Input[str] description: Human-readable description for the vip. Changing
               this updates the description of the existing vip.
        :param pulumi.Input[str] floating_ip: A *Networking* Floating IP that will be associated
               with the vip. The Floating IP must be provisioned already.
        :param pulumi.Input[str] name: The name of the vip. Changing this updates the name of
               the existing vip.
        :param pulumi.Input[dict] persistence: Omit this field to prevent session persistence.
               The persistence object structure is documented below. Changing this updates
               the persistence of the existing vip.
        :param pulumi.Input[str] pool_id: The ID of the pool with which the vip is associated.
               Changing this updates the pool_id of the existing vip.
        :param pulumi.Input[float] port: The port on which to listen for client traffic. Changing
               this creates a new vip.
        :param pulumi.Input[str] protocol: The protocol - can be either 'TCP, 'HTTP', or
               HTTPS'. Changing this creates a new vip.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a VIP. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               VIP.
        :param pulumi.Input[str] subnet_id: The network on which to allocate the vip's address. A
               tenant can only create vips on networks authorized by policy (e.g. networks
               that belong to them or networks that are shared). Changing this creates a
               new vip.
        :param pulumi.Input[str] tenant_id: The owner of the vip. Required if admin wants to
               create a vip member for another tenant. Changing this creates a new vip.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['address'] = address
            __props__['admin_state_up'] = admin_state_up
            __props__['conn_limit'] = conn_limit
            __props__['description'] = description
            __props__['floating_ip'] = floating_ip
            __props__['name'] = name
            __props__['persistence'] = persistence
            if pool_id is None:
                raise TypeError("Missing required property 'pool_id'")
            __props__['pool_id'] = pool_id
            if port is None:
                raise TypeError("Missing required property 'port'")
            __props__['port'] = port
            if protocol is None:
                raise TypeError("Missing required property 'protocol'")
            __props__['protocol'] = protocol
            __props__['region'] = region
            if subnet_id is None:
                raise TypeError("Missing required property 'subnet_id'")
            __props__['subnet_id'] = subnet_id
            __props__['tenant_id'] = tenant_id
            __props__['port_id'] = None
        super(Vip, __self__).__init__(
            'openstack:loadbalancer/vip:Vip',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, address=None, admin_state_up=None, conn_limit=None, description=None, floating_ip=None, name=None, persistence=None, pool_id=None, port=None, port_id=None, protocol=None, region=None, subnet_id=None, tenant_id=None):
        """
        Get an existing Vip resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: The IP address of the vip. Changing this creates a new
               vip.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the vip.
               Acceptable values are "true" and "false". Changing this value updates the
               state of the existing vip.
        :param pulumi.Input[float] conn_limit: The maximum number of connections allowed for the
               vip. Default is -1, meaning no limit. Changing this updates the conn_limit
               of the existing vip.
        :param pulumi.Input[str] description: Human-readable description for the vip. Changing
               this updates the description of the existing vip.
        :param pulumi.Input[str] floating_ip: A *Networking* Floating IP that will be associated
               with the vip. The Floating IP must be provisioned already.
        :param pulumi.Input[str] name: The name of the vip. Changing this updates the name of
               the existing vip.
        :param pulumi.Input[dict] persistence: Omit this field to prevent session persistence.
               The persistence object structure is documented below. Changing this updates
               the persistence of the existing vip.
        :param pulumi.Input[str] pool_id: The ID of the pool with which the vip is associated.
               Changing this updates the pool_id of the existing vip.
        :param pulumi.Input[float] port: The port on which to listen for client traffic. Changing
               this creates a new vip.
        :param pulumi.Input[str] port_id: Port UUID for this VIP at associated floating IP (if any).
        :param pulumi.Input[str] protocol: The protocol - can be either 'TCP, 'HTTP', or
               HTTPS'. Changing this creates a new vip.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a VIP. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               VIP.
        :param pulumi.Input[str] subnet_id: The network on which to allocate the vip's address. A
               tenant can only create vips on networks authorized by policy (e.g. networks
               that belong to them or networks that are shared). Changing this creates a
               new vip.
        :param pulumi.Input[str] tenant_id: The owner of the vip. Required if admin wants to
               create a vip member for another tenant. Changing this creates a new vip.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["address"] = address
        __props__["admin_state_up"] = admin_state_up
        __props__["conn_limit"] = conn_limit
        __props__["description"] = description
        __props__["floating_ip"] = floating_ip
        __props__["name"] = name
        __props__["persistence"] = persistence
        __props__["pool_id"] = pool_id
        __props__["port"] = port
        __props__["port_id"] = port_id
        __props__["protocol"] = protocol
        __props__["region"] = region
        __props__["subnet_id"] = subnet_id
        __props__["tenant_id"] = tenant_id
        return Vip(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Listener(pulumi.CustomResource):
    admin_state_up: pulumi.Output[bool]
    """
    The administrative state of the Listener.
    A valid value is true (UP) or false (DOWN).
    """
    connection_limit: pulumi.Output[float]
    """
    The maximum number of connections allowed
    for the Listener.
    """
    default_pool_id: pulumi.Output[str]
    """
    The ID of the default pool with which the
    Listener is associated.
    """
    default_tls_container_ref: pulumi.Output[str]
    """
    A reference to a Barbican Secrets
    container which stores TLS information. This is required if the protocol
    is `TERMINATED_HTTPS`. See
    [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
    for more information.
    """
    description: pulumi.Output[str]
    """
    Human-readable description for the Listener.
    """
    insert_headers: pulumi.Output[dict]
    """
    The list of key value pairs representing headers to insert
    into the request before it is sent to the backend members. Changing this updates the headers of the
    existing listener.
    """
    loadbalancer_id: pulumi.Output[str]
    """
    The load balancer on which to provision this
    Listener. Changing this creates a new Listener.
    """
    name: pulumi.Output[str]
    """
    Human-readable name for the Listener. Does not have
    to be unique.
    """
    protocol: pulumi.Output[str]
    """
    The protocol - can either be TCP, HTTP, HTTPS,
    TERMINATED_HTTPS or UDP (supported only in Octavia). Changing this creates a
    new Listener.
    """
    protocol_port: pulumi.Output[float]
    """
    The port on which to listen for client traffic.
    Changing this creates a new Listener.
    """
    region: pulumi.Output[str]
    """
    The region in which to obtain the V2 Networking client.
    A Networking client is needed to create an . If omitted, the
    `region` argument of the provider is used. Changing this creates a new
    Listener.
    """
    sni_container_refs: pulumi.Output[list]
    """
    A list of references to Barbican Secrets
    containers which store SNI information. See
    [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
    for more information.
    """
    tenant_id: pulumi.Output[str]
    """
    Required for admins. The UUID of the tenant who owns
    the Listener.  Only administrative users can specify a tenant UUID
    other than their own. Changing this creates a new Listener.
    """
    timeout_client_data: pulumi.Output[float]
    """
    The client inactivity timeout in milliseconds.
    """
    timeout_member_connect: pulumi.Output[float]
    """
    The member connection timeout in milliseconds.
    """
    timeout_member_data: pulumi.Output[float]
    """
    The member inactivity timeout in milliseconds.
    """
    timeout_tcp_inspect: pulumi.Output[float]
    """
    The time in milliseconds, to wait for additional
    TCP packets for content inspection.
    """
    def __init__(__self__, resource_name, opts=None, admin_state_up=None, connection_limit=None, default_pool_id=None, default_tls_container_ref=None, description=None, insert_headers=None, loadbalancer_id=None, name=None, protocol=None, protocol_port=None, region=None, sni_container_refs=None, tenant_id=None, timeout_client_data=None, timeout_member_connect=None, timeout_member_data=None, timeout_tcp_inspect=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a V2 listener resource within OpenStack.



        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the Listener.
               A valid value is true (UP) or false (DOWN).
        :param pulumi.Input[float] connection_limit: The maximum number of connections allowed
               for the Listener.
        :param pulumi.Input[str] default_pool_id: The ID of the default pool with which the
               Listener is associated.
        :param pulumi.Input[str] default_tls_container_ref: A reference to a Barbican Secrets
               container which stores TLS information. This is required if the protocol
               is `TERMINATED_HTTPS`. See
               [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
               for more information.
        :param pulumi.Input[str] description: Human-readable description for the Listener.
        :param pulumi.Input[dict] insert_headers: The list of key value pairs representing headers to insert
               into the request before it is sent to the backend members. Changing this updates the headers of the
               existing listener.
        :param pulumi.Input[str] loadbalancer_id: The load balancer on which to provision this
               Listener. Changing this creates a new Listener.
        :param pulumi.Input[str] name: Human-readable name for the Listener. Does not have
               to be unique.
        :param pulumi.Input[str] protocol: The protocol - can either be TCP, HTTP, HTTPS,
               TERMINATED_HTTPS or UDP (supported only in Octavia). Changing this creates a
               new Listener.
        :param pulumi.Input[float] protocol_port: The port on which to listen for client traffic.
               Changing this creates a new Listener.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an . If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               Listener.
        :param pulumi.Input[list] sni_container_refs: A list of references to Barbican Secrets
               containers which store SNI information. See
               [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
               for more information.
        :param pulumi.Input[str] tenant_id: Required for admins. The UUID of the tenant who owns
               the Listener.  Only administrative users can specify a tenant UUID
               other than their own. Changing this creates a new Listener.
        :param pulumi.Input[float] timeout_client_data: The client inactivity timeout in milliseconds.
        :param pulumi.Input[float] timeout_member_connect: The member connection timeout in milliseconds.
        :param pulumi.Input[float] timeout_member_data: The member inactivity timeout in milliseconds.
        :param pulumi.Input[float] timeout_tcp_inspect: The time in milliseconds, to wait for additional
               TCP packets for content inspection.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['admin_state_up'] = admin_state_up
            __props__['connection_limit'] = connection_limit
            __props__['default_pool_id'] = default_pool_id
            __props__['default_tls_container_ref'] = default_tls_container_ref
            __props__['description'] = description
            __props__['insert_headers'] = insert_headers
            if loadbalancer_id is None:
                raise TypeError("Missing required property 'loadbalancer_id'")
            __props__['loadbalancer_id'] = loadbalancer_id
            __props__['name'] = name
            if protocol is None:
                raise TypeError("Missing required property 'protocol'")
            __props__['protocol'] = protocol
            if protocol_port is None:
                raise TypeError("Missing required property 'protocol_port'")
            __props__['protocol_port'] = protocol_port
            __props__['region'] = region
            __props__['sni_container_refs'] = sni_container_refs
            __props__['tenant_id'] = tenant_id
            __props__['timeout_client_data'] = timeout_client_data
            __props__['timeout_member_connect'] = timeout_member_connect
            __props__['timeout_member_data'] = timeout_member_data
            __props__['timeout_tcp_inspect'] = timeout_tcp_inspect
        super(Listener, __self__).__init__(
            'openstack:loadbalancer/listener:Listener',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, admin_state_up=None, connection_limit=None, default_pool_id=None, default_tls_container_ref=None, description=None, insert_headers=None, loadbalancer_id=None, name=None, protocol=None, protocol_port=None, region=None, sni_container_refs=None, tenant_id=None, timeout_client_data=None, timeout_member_connect=None, timeout_member_data=None, timeout_tcp_inspect=None):
        """
        Get an existing Listener resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] admin_state_up: The administrative state of the Listener.
               A valid value is true (UP) or false (DOWN).
        :param pulumi.Input[float] connection_limit: The maximum number of connections allowed
               for the Listener.
        :param pulumi.Input[str] default_pool_id: The ID of the default pool with which the
               Listener is associated.
        :param pulumi.Input[str] default_tls_container_ref: A reference to a Barbican Secrets
               container which stores TLS information. This is required if the protocol
               is `TERMINATED_HTTPS`. See
               [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
               for more information.
        :param pulumi.Input[str] description: Human-readable description for the Listener.
        :param pulumi.Input[dict] insert_headers: The list of key value pairs representing headers to insert
               into the request before it is sent to the backend members. Changing this updates the headers of the
               existing listener.
        :param pulumi.Input[str] loadbalancer_id: The load balancer on which to provision this
               Listener. Changing this creates a new Listener.
        :param pulumi.Input[str] name: Human-readable name for the Listener. Does not have
               to be unique.
        :param pulumi.Input[str] protocol: The protocol - can either be TCP, HTTP, HTTPS,
               TERMINATED_HTTPS or UDP (supported only in Octavia). Changing this creates a
               new Listener.
        :param pulumi.Input[float] protocol_port: The port on which to listen for client traffic.
               Changing this creates a new Listener.
        :param pulumi.Input[str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an . If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               Listener.
        :param pulumi.Input[list] sni_container_refs: A list of references to Barbican Secrets
               containers which store SNI information. See
               [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
               for more information.
        :param pulumi.Input[str] tenant_id: Required for admins. The UUID of the tenant who owns
               the Listener.  Only administrative users can specify a tenant UUID
               other than their own. Changing this creates a new Listener.
        :param pulumi.Input[float] timeout_client_data: The client inactivity timeout in milliseconds.
        :param pulumi.Input[float] timeout_member_connect: The member connection timeout in milliseconds.
        :param pulumi.Input[float] timeout_member_data: The member inactivity timeout in milliseconds.
        :param pulumi.Input[float] timeout_tcp_inspect: The time in milliseconds, to wait for additional
               TCP packets for content inspection.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["admin_state_up"] = admin_state_up
        __props__["connection_limit"] = connection_limit
        __props__["default_pool_id"] = default_pool_id
        __props__["default_tls_container_ref"] = default_tls_container_ref
        __props__["description"] = description
        __props__["insert_headers"] = insert_headers
        __props__["loadbalancer_id"] = loadbalancer_id
        __props__["name"] = name
        __props__["protocol"] = protocol
        __props__["protocol_port"] = protocol_port
        __props__["region"] = region
        __props__["sni_container_refs"] = sni_container_refs
        __props__["tenant_id"] = tenant_id
        __props__["timeout_client_data"] = timeout_client_data
        __props__["timeout_member_connect"] = timeout_member_connect
        __props__["timeout_member_data"] = timeout_member_data
        __props__["timeout_tcp_inspect"] = timeout_tcp_inspect
        return Listener(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

